@@ -1,5 +1,7 @@
 import logging
 import threading
+from concurrent.futures import ThreadPoolExecutor
+from multiprocessing.pool import ThreadPool
 from typing import Any
 
 
@@ -7,7 +9,7 @@ def __thread_fn__(event: threading.Event, fn: callable, *args: Any, **kwargs: An
     pass
 
 
-def RunInThread(fn: callable, *args: Any, **kwargs: Any) -> threading.Event:
+def RunInThread(fn: callable, *args: Any, executor: ThreadPoolExecutor = None, **kwargs: Any) -> threading.Event:
     event = threading.Event()
 
     def thread_fn():
@@ -18,8 +20,11 @@ def RunInThread(fn: callable, *args: Any, **kwargs: Any) -> threading.Event:
                 logging.error(e)
         event.set()
 
-    t = threading.Thread(target=thread_fn)
-    t.start()
+    if executor is None:
+        t = threading.Thread(target=thread_fn)
+        t.start()
+    else:
+        executor.submit(thread_fn)
     return event
 
 
